Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(976)

Unified Diff: src/stub-cache.h

Issue 131663003: Make the strict-mode calling convention for contextual calls the default one. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Fix arm port Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/runtime.cc ('k') | src/stub-cache.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/stub-cache.h
diff --git a/src/stub-cache.h b/src/stub-cache.h
index 2d061ab2a98687ba4a07f9e05070ce4bbabb0f8b..360bbfb5ade6ee53b7925cb62696742ef287f4c0 100644
--- a/src/stub-cache.h
+++ b/src/stub-cache.h
@@ -929,13 +929,9 @@ class CallStubCompiler: public StubCompiler {
PropertyIndex index,
Handle<Name> name);
- // Patch the global proxy over the global object if the global object is the
- // receiver.
- static void FetchGlobalProxy(MacroAssembler* masm,
- Register target,
- Register function);
- void PatchGlobalProxy(Handle<Object> object, Register function);
- void PatchGlobalProxy(Handle<Object> object, Handle<JSFunction> function);
+ // Patch the implicit receiver over the global object if the global object is
+ // the receiver.
+ void PatchImplicitReceiver(Handle<Object> object);
// Returns the register containing the holder of |name|.
Register HandlerFrontendHeader(Handle<Object> object,
« no previous file with comments | « src/runtime.cc ('k') | src/stub-cache.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698